<?php
/* Author: Alessio Cecchi */

$labels = array();
$labels['createfilter'] = 'Crea filtro...';
$labels['createfilterbased'] = 'Crea un filtro basato su questo messaggio';

$messages = array();

?>