<?php
/* Author: Mike Constabel */

$labels = array();
$labels['createfilter'] = 'Erstelle Filter...';
$labels['createfilterbased'] = 'Erstelle einen auf dieser Nachricht basierenden Filter';

$messages = array();

?>